// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Activity {
  id: number
  title: string
  description: string
  time: string
  location: string
  category: string
  capacity: number
  participants: number
  status: 'upcoming' | 'ongoing' | 'ended'
  organizer: {
    id: number
    name: string
    avatar: string
    phone: string
  }
  cover: string
  tags: string[]
  price: number
  requirements?: string[]
}

export interface ActivityRegistration {
  id: number
  activityId: number
  userId: number
  status: 'pending' | 'confirmed' | 'cancelled'
  registrationTime: string
  notes?: string
}

export interface ActivityComment {
  id: number
  activityId: number
  userId: number
  userName: string
  userAvatar: string
  content: string
  createTime: string
  likes: number
  images?: string[]
}

// 模拟数据
const mockActivities: Activity[] = [
  {
    id: 1,
    title: '太极拳晨练班',
    description: '由专业老师指导的太极拳晨练活动，适合初学者。',
    time: '2024-03-21 07:30:00',
    location: '社区活动中心',
    category: 'sports',
    capacity: 30,
    participants: 18,
    status: 'upcoming',
    organizer: {
      id: 1,
      name: '王教练',
      avatar: 'https://example.com/avatar1.jpg',
      phone: '13800138000'
    },
    cover: 'https://example.com/taichi.jpg',
    tags: ['运动', '太极拳', '健康'],
    price: 0
  },
  {
    id: 2,
    title: '书法艺术讲座',
    description: '邀请著名书法家分享书法技巧和艺术欣赏。',
    time: '2024-03-22 14:00:00',
    location: '文化活动室',
    category: 'culture',
    capacity: 50,
    participants: 35,
    status: 'upcoming',
    organizer: {
      id: 2,
      name: '李老师',
      avatar: 'https://example.com/avatar2.jpg',
      phone: '13900139000'
    },
    cover: 'https://example.com/calligraphy.jpg',
    tags: ['文化', '书法', '艺术'],
    price: 20
  }
]

const mockRegistrations: ActivityRegistration[] = [
  {
    id: 1,
    activityId: 1,
    userId: 10001,
    status: 'confirmed',
    registrationTime: '2024-03-19 10:00:00',
    notes: '需要准备运动服装'
  }
]

const mockComments: ActivityComment[] = [
  {
    id: 1,
    activityId: 1,
    userId: 10001,
    userName: '张三',
    userAvatar: 'https://example.com/user1.jpg',
    content: '活动很有意思，老师讲解很细致。',
    createTime: '2024-03-19 15:00:00',
    likes: 5,
    images: ['https://example.com/photo1.jpg']
  }
]

// 活动分类
export const activityCategories = [
  { label: '体育运动', value: 'sports' },
  { label: '文化艺术', value: 'culture' },
  { label: '健康讲座', value: 'health' },
  { label: '娱乐休闲', value: 'entertainment' },
  { label: '志愿服务', value: 'volunteer' }
]

// 模拟 API 接口
export const activityApi = {
  // 获取活动列表
  async getActivities(params: {
    category?: string
    status?: string
    page?: number
    size?: number
  }): Promise<{
    total: number
    records: Activity[]
  }> {
    await delay(300)
    let result = [...mockActivities]
    
    if (params.category) {
      result = result.filter(activity => activity.category === params.category)
    }
    if (params.status) {
      result = result.filter(activity => activity.status === params.status)
    }

    return {
      total: result.length,
      records: result.slice(
        ((params.page || 1) - 1) * (params.size || 10),
        (params.page || 1) * (params.size || 10)
      )
    }
  },

  // 获取活动详情
  async getActivityDetail(id: number): Promise<Activity | undefined> {
    await delay(200)
    return mockActivities.find(activity => activity.id === id)
  },

  // 报名活动
  async registerActivity(activityId: number, userId: number, notes?: string): Promise<ActivityRegistration> {
    await delay(500)
    const newRegistration = {
      id: mockRegistrations.length + 1,
      activityId,
      userId,
      status: 'confirmed' as const,
      registrationTime: new Date().toISOString(),
      notes
    }
    mockRegistrations.push(newRegistration)
    
    // 更新参与人数
    const activity = mockActivities.find(a => a.id === activityId)
    if (activity) {
      activity.participants++
    }
    
    return newRegistration
  },

  // 取消报名
  async cancelRegistration(id: number): Promise<void> {
    await delay(300)
    const registration = mockRegistrations.find(r => r.id === id)
    if (registration) {
      registration.status = 'cancelled'
      
      // 更新参与人数
      const activity = mockActivities.find(a => a.id === registration.activityId)
      if (activity) {
        activity.participants--
      }
    }
  },

  // 获取活动评论
  async getComments(activityId: number): Promise<ActivityComment[]> {
    await delay(200)
    return mockComments.filter(comment => comment.activityId === activityId)
  },

  // 发表评论
  async addComment(comment: Omit<ActivityComment, 'id' | 'likes'>): Promise<ActivityComment> {
    await delay(300)
    const newComment = {
      id: mockComments.length + 1,
      ...comment,
      likes: 0
    }
    mockComments.push(newComment)
    return newComment
  },

  // 点赞评论
  async likeComment(id: number): Promise<void> {
    await delay(200)
    const comment = mockComments.find(c => c.id === id)
    if (comment) {
      comment.likes++
    }
  },

  // 获取推荐活动
  async getRecommendedActivities(userId: number): Promise<Activity[]> {
    await delay(300)
    return mockActivities
      .filter(activity => activity.status === 'upcoming')
      .slice(0, 3)
  },

  // 获取用户参与的活动
  async getUserActivities(userId: number): Promise<Activity[]> {
    await delay(300)
    const userRegistrations = mockRegistrations
      .filter(r => r.userId === userId && r.status === 'confirmed')
      .map(r => r.activityId)
    return mockActivities.filter(activity => userRegistrations.includes(activity.id))
  },

  // 上传活动图片
  async uploadImage(file: File): Promise<string> {
    await delay(1000)
    return `https://example.com/activities/${file.name}`
  }
} 