// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Post {
  id: number
  title: string
  content: string
  createTime: string
  author: {
    id: number
    name: string
    avatar: string
  }
  images?: string[]
  tags: string[]
  likes: number
  comments: number
  isLiked: boolean
  isFollowing: boolean
}

export interface Topic {
  id: number
  rank: number
  title: string
  hot: string
}

export interface Comment {
  id: number
  postId: number
  userId: number
  userName: string
  content: string
  time: string
  likes: number
  replies?: Comment[]
}

export interface User {
  id: number
  name: string
  avatar: string
  signature: string
  isFollowing: boolean
}

// 模拟数据
const mockPosts: Post[] = [
  {
    id: 1,
    title: '今天参加了太极拳课程',
    content: '今天和社区的老朋友们一起学习太极拳，感觉特别好！',
    createTime: '2024-03-20 10:30',
    author: {
      id: 1,
      name: '张大爷',
      avatar: 'https://example.com/avatar1.jpg'
    },
    images: [
      'https://example.com/taichi1.jpg',
      'https://example.com/taichi2.jpg'
    ],
    tags: ['太极拳', '健康运动', '社区活动'],
    likes: 28,
    comments: 12,
    isLiked: false,
    isFollowing: false
  },
  {
    id: 2,
    title: '分享一个养生小妙方',
    content: '每天坚持喝一杯蜂蜜水，对身体很有好处...',
    createTime: '2024-03-19 15:20',
    author: {
      id: 2,
      name: '李奶奶',
      avatar: 'https://example.com/avatar2.jpg'
    },
    tags: ['养生', '健康', '生活分享'],
    likes: 45,
    comments: 18,
    isLiked: true,
    isFollowing: true
  }
]

const mockTopics: Topic[] = [
  {
    id: 1,
    rank: 1,
    title: '健康养生',
    hot: '999+'
  },
  {
    id: 2,
    rank: 2,
    title: '广场舞大赛',
    hot: '888+'
  },
  {
    id: 3,
    rank: 3,
    title: '社区活动',
    hot: '666+'
  }
]

const mockUsers: User[] = [
  {
    id: 1,
    name: '李奶奶',
    avatar: 'https://example.com/avatar2.jpg',
    signature: '快乐生活每一天',
    isFollowing: true
  },
  {
    id: 2,
    name: '王大爷',
    avatar: 'https://example.com/avatar3.jpg',
    signature: '爱好太极拳',
    isFollowing: false
  }
]

// 模拟 API 接口
export const communityApi = {
  // 获取帖子列表
  async getPosts(params: {
    category?: string
    page?: number
    size?: number
    keyword?: string
  }): Promise<{
    total: number
    records: Post[]
  }> {
    await delay(300)
    let result = [...mockPosts]
    
    if (params.category) {
      result = result.filter(post => post.tags.includes(params.category))
    }
    
    if (params.keyword) {
      const keyword = params.keyword.toLowerCase()
      result = result.filter(post => 
        post.title.toLowerCase().includes(keyword) ||
        post.content.toLowerCase().includes(keyword)
      )
    }

    return {
      total: result.length,
      records: result.slice(
        ((params.page || 1) - 1) * (params.size || 10),
        (params.page || 1) * (params.size || 10)
      )
    }
  },

  // 发布帖子
  async createPost(post: Omit<Post, 'id' | 'createTime' | 'likes' | 'comments'>): Promise<Post> {
    await delay(500)
    const newPost = {
      id: mockPosts.length + 1,
      createTime: new Date().toISOString(),
      likes: 0,
      comments: 0,
      ...post
    }
    mockPosts.unshift(newPost)
    return newPost
  },

  // 获取热门话题
  async getHotTopics(): Promise<Topic[]> {
    await delay(300)
    return mockTopics
  },

  // 获取活跃用户
  async getActiveUsers(): Promise<User[]> {
    await delay(300)
    return mockUsers
  },

  // 关注/取消关注用户
  async toggleFollow(userId: number): Promise<void> {
    await delay(200)
    const user = mockUsers.find(u => u.id === userId)
    if (user) {
      user.isFollowing = !user.isFollowing
    }
  },

  // 点赞/取消点赞帖子
  async toggleLike(postId: number): Promise<void> {
    await delay(200)
    const post = mockPosts.find(p => p.id === postId)
    if (post) {
      post.isLiked = !post.isLiked
      post.likes += post.isLiked ? 1 : -1
    }
  },

  // 获取评论列表
  async getComments(postId: number): Promise<Comment[]> {
    await delay(300)
    return mockComments.filter(comment => comment.postId === postId)
  },

  // 添加评论
  async addComment(comment: Omit<Comment, 'id' | 'time' | 'likes'>): Promise<Comment> {
    await delay(300)
    const newComment = {
      id: Date.now(),
      time: new Date().toISOString(),
      likes: 0,
      ...comment
    }
    mockComments.push(newComment)
    return newComment
  },

  // 上传图片
  async uploadImage(file: File): Promise<string> {
    await delay(1000)
    return URL.createObjectURL(file)
  },

  // 获取推荐帖子
  async getRecommendedPosts(): Promise<Post[]> {
    await delay(300)
    return mockPosts
      .sort(() => Math.random() - 0.5)
      .slice(0, 3)
  }
} 