// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Device {
  id: number
  name: string
  type: string
  model: string
  status: 'online' | 'offline'
  battery: number
  lastUpdate: string
  bindTime: string
  settings: {
    [key: string]: any
  }
}

export interface HealthData {
  id: number
  deviceId: number
  type: string
  value: number
  unit: string
  time: string
  status: 'normal' | 'warning' | 'danger'
}

export interface DeviceAlert {
  id: number
  deviceId: number
  type: string
  level: 'info' | 'warning' | 'danger'
  content: string
  time: string
  handled: boolean
}

export interface LocationRecord {
  id: number
  deviceId: number
  latitude: number
  longitude: number
  address: string
  time: string
  accuracy: number
}

// 模拟数据
const mockDevices: Device[] = [
  {
    id: 1,
    name: '智能手环',
    type: 'bracelet',
    model: 'HC-001',
    status: 'online',
    battery: 85,
    lastUpdate: '2024-03-20 10:00:00',
    bindTime: '2024-01-01',
    settings: {
      heartRateMonitor: true,
      sleepTracker: true,
      stepCounter: true,
      displayBrightness: 80
    }
  },
  {
    id: 2,
    name: 'GPS定位器',
    type: 'locator',
    model: 'GL-002',
    status: 'online',
    battery: 92,
    lastUpdate: '2024-03-20 10:00:00',
    bindTime: '2024-01-15',
    settings: {
      locationInterval: 5,
      geofenceRadius: 1000,
      powerSaving: false
    }
  },
  {
    id: 3,
    name: '血压计',
    type: 'monitor',
    model: 'BP-003',
    status: 'offline',
    battery: 20,
    lastUpdate: '2024-03-19 15:30:00',
    bindTime: '2024-02-01',
    settings: {
      autoMeasure: true,
      measureInterval: 60,
      alarmThreshold: {
        high: 140,
        low: 90
      }
    }
  }
]

const mockHealthData: HealthData[] = [
  {
    id: 1,
    deviceId: 1,
    type: 'heartRate',
    value: 75,
    unit: 'bpm',
    time: '2024-03-20 10:00:00',
    status: 'normal'
  },
  {
    id: 2,
    deviceId: 1,
    type: 'steps',
    value: 6500,
    unit: 'steps',
    time: '2024-03-20 10:00:00',
    status: 'normal'
  },
  {
    id: 3,
    deviceId: 3,
    type: 'bloodPressure',
    value: 120,
    unit: 'mmHg',
    time: '2024-03-19 15:30:00',
    status: 'normal'
  }
]

const mockAlerts: DeviceAlert[] = [
  {
    id: 1,
    deviceId: 3,
    type: 'lowBattery',
    level: 'warning',
    content: '设备电量低于20%，请及时充电',
    time: '2024-03-20 09:00:00',
    handled: false
  },
  {
    id: 2,
    deviceId: 1,
    type: 'abnormalHeartRate',
    level: 'danger',
    content: '检测到异常心率，请注意休息',
    time: '2024-03-20 08:30:00',
    handled: true
  }
]

const mockLocations: LocationRecord[] = [
  {
    id: 1,
    deviceId: 2,
    latitude: 39.9042,
    longitude: 116.4074,
    address: '北京市东城区',
    time: '2024-03-20 10:00:00',
    accuracy: 10
  },
  {
    id: 2,
    deviceId: 2,
    latitude: 39.9043,
    longitude: 116.4075,
    address: '北京市东城区',
    time: '2024-03-20 09:55:00',
    accuracy: 15
  }
]

// 模拟 API 接口
export const deviceApi = {
  // 获取设备列表
  async getDevices(): Promise<Device[]> {
    await delay(300)
    return mockDevices
  },

  // 获取设备详情
  async getDeviceDetail(id: number): Promise<Device | undefined> {
    await delay(200)
    return mockDevices.find(device => device.id === id)
  },

  // 更新设备设置
  async updateDeviceSettings(id: number, settings: any): Promise<void> {
    await delay(300)
    const device = mockDevices.find(d => d.id === id)
    if (device) {
      device.settings = { ...device.settings, ...settings }
    }
  },

  // 获取健康数据
  async getHealthData(deviceId: number, type?: string): Promise<HealthData[]> {
    await delay(300)
    return mockHealthData.filter(data => 
      data.deviceId === deviceId && 
      (type ? data.type === type : true)
    )
  },

  // 获取设备告警
  async getDeviceAlerts(deviceId?: number): Promise<DeviceAlert[]> {
    await delay(300)
    return mockAlerts.filter(alert => 
      deviceId ? alert.deviceId === deviceId : true
    )
  },

  // 处理告警
  async handleAlert(id: number): Promise<void> {
    await delay(200)
    const alert = mockAlerts.find(a => a.id === id)
    if (alert) {
      alert.handled = true
    }
  },

  // 获取位置记录
  async getLocationRecords(deviceId: number, params: {
    startTime?: string
    endTime?: string
    limit?: number
  }): Promise<LocationRecord[]> {
    await delay(300)
    return mockLocations.filter(record => record.deviceId === deviceId)
  },

  // 绑定设备
  async bindDevice(params: {
    name: string
    type: string
    model: string
  }): Promise<Device> {
    await delay(500)
    const newDevice = {
      id: mockDevices.length + 1,
      ...params,
      status: 'online',
      battery: 100,
      lastUpdate: new Date().toISOString(),
      bindTime: new Date().toISOString(),
      settings: {}
    }
    mockDevices.push(newDevice as Device)
    return newDevice as Device
  },

  // 解绑设备
  async unbindDevice(id: number): Promise<void> {
    await delay(300)
    const index = mockDevices.findIndex(d => d.id === id)
    if (index !== -1) {
      mockDevices.splice(index, 1)
    }
  },

  // 远程控制设备
  async controlDevice(id: number, command: string, params?: any): Promise<void> {
    await delay(300)
    // 模拟设备控制
    console.log(`控制设备 ${id}：${command}`, params)
  },

  // 获取设备统计数据
  async getDeviceStats(id: number): Promise<{
    totalSteps: number
    avgHeartRate: number
    sleepHours: number
    activeMinutes: number
  }> {
    await delay(300)
    return {
      totalSteps: 8500,
      avgHeartRate: 75,
      sleepHours: 7.5,
      activeMinutes: 120
    }
  }
} 