// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Meal {
  id: number
  time: string
  name: string
  description: string
  calories: number
  nutrition: {
    protein: number
    carbs: number
    fat: number
  }
  status: 'pending' | 'current' | 'done'
  ingredients: Array<{
    name: string
    amount: string
  }>
}

export interface NutritionReport {
  dailyCalories: number
  nutrition: {
    protein: number
    carbs: number
    fat: number
  }
  suggestions: string[]
  status: 'good' | 'warning' | 'bad'
}

export interface DietPlan {
  id: number
  date: string
  meals: Meal[]
  totalCalories: number
  preferences: string[]
  allergies: string[]
}

// 模拟数据
const mockMeals: Meal[] = [
  {
    id: 1,
    time: '08:00',
    name: '营养早餐',
    description: '牛奶燕麦粥配鸡蛋',
    calories: 300,
    nutrition: {
      protein: 15,
      carbs: 40,
      fat: 10
    },
    status: 'done',
    ingredients: [
      { name: '燕麦', amount: '50g' },
      { name: '牛奶', amount: '200ml' },
      { name: '鸡蛋', amount: '1个' }
    ]
  },
  {
    id: 2,
    time: '12:00',
    name: '健康午餐',
    description: '清蒸鱼配时蔬',
    calories: 450,
    nutrition: {
      protein: 25,
      carbs: 35,
      fat: 15
    },
    status: 'pending',
    ingredients: [
      { name: '鲈鱼', amount: '200g' },
      { name: '西兰花', amount: '100g' },
      { name: '胡萝卜', amount: '50g' }
    ]
  }
]

const mockDietPlans: DietPlan[] = [
  {
    id: 1,
    date: '2024-03-20',
    meals: mockMeals,
    totalCalories: 1800,
    preferences: ['清淡', '少油'],
    allergies: ['海鲜']
  }
]

// 模拟 API 接口
export const dietApi = {
  // 获取今日膳食
  async getTodayMeals(): Promise<Meal[]> {
    await delay(300)
    return mockMeals
  },

  // 获取营养报告
  async getNutritionReport(): Promise<NutritionReport> {
    await delay(500)
    return {
      dailyCalories: 1800,
      nutrition: {
        protein: 80,
        carbs: 250,
        fat: 60
      },
      suggestions: [
        '可以适当增加优质蛋白的摄入',
        '建议多补充维生素C',
        '注意补充水分'
      ],
      status: 'good'
    }
  },

  // 更新用餐状态
  async updateMealStatus(id: number, status: 'pending' | 'current' | 'done'): Promise<void> {
    await delay(200)
    const meal = mockMeals.find(m => m.id === id)
    if (meal) {
      meal.status = status
    }
  },

  // 获取膳食计划
  async getDietPlan(date: string): Promise<DietPlan | undefined> {
    await delay(300)
    return mockDietPlans.find(plan => plan.date === date)
  },

  // 创建膳食计划
  async createDietPlan(plan: Omit<DietPlan, 'id'>): Promise<DietPlan> {
    await delay(500)
    const newPlan = {
      id: mockDietPlans.length + 1,
      ...plan
    }
    mockDietPlans.push(newPlan)
    return newPlan
  },

  // 调整膳食
  async adjustMeal(mealId: number, adjustments: Partial<Meal>): Promise<Meal> {
    await delay(300)
    const meal = mockMeals.find(m => m.id === mealId)
    if (!meal) {
      throw new Error('Meal not found')
    }
    Object.assign(meal, adjustments)
    return meal
  },

  // 获取推荐食谱
  async getRecommendedRecipes(): Promise<Array<{
    id: number
    name: string
    calories: number
    suitable: string[]
  }>> {
    await delay(300)
    return [
      {
        id: 1,
        name: '清蒸鲈鱼',
        calories: 200,
        suitable: ['高蛋白', '低脂肪']
      },
      {
        id: 2,
        name: '五谷杂粮粥',
        calories: 150,
        suitable: ['易消化', '营养均衡']
      }
    ]
  }
} 