// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Course {
  id: number
  title: string
  description: string
  cover: string
  category: string
  students: number
  progress: number
  videoUrl: string
  chapters: Array<{
    id: number
    title: string
    description: string
  }>
}

export interface LiveChannel {
  id: number
  title: string
  anchor: string
  cover: string
  status: 'live' | 'upcoming' | 'ended'
  viewers: number
  likes: number
}

export interface Game {
  id: number
  name: string
  icon: string
  players: number
  type: string
  description: string
}

export interface Book {
  id: number
  title: string
  author: string
  cover: string
  progress: number
  category: string
  description: string
}

export interface InterestGroup {
  id: number
  name: string
  members: number
  tags: string[]
  joined: boolean
  description: string
  activities: number
}

// 模拟数据
const mockCourses: Course[] = [
  {
    id: 1,
    title: '太极拳基础教学',
    description: '适合老年人的太极拳入门课程',
    cover: 'https://example.com/course1.jpg',
    category: 'health',
    students: 128,
    progress: 60,
    videoUrl: 'https://example.com/course1.mp4',
    chapters: [
      { id: 1, title: '基础站姿', description: '学习太极拳的基本站姿' },
      { id: 2, title: '手型要领', description: '掌握太极拳的手型要求' }
    ]
  },
  {
    id: 2,
    title: '书法艺术入门',
    description: '从基础开始学习书法艺术',
    cover: 'https://example.com/course2.jpg',
    category: 'culture',
    students: 89,
    progress: 30,
    videoUrl: 'https://example.com/course2.mp4',
    chapters: [
      { id: 1, title: '工具准备', description: '认识书法工具' },
      { id: 2, title: '基本笔画', description: '练习基本笔画' }
    ]
  }
]

const mockLiveChannels: LiveChannel[] = [
  {
    id: 1,
    title: '广场舞教学',
    anchor: '张老师',
    cover: 'https://example.com/live1.jpg',
    status: 'live',
    viewers: 256,
    likes: 128
  },
  {
    id: 2,
    title: '戏曲欣赏',
    anchor: '李老师',
    cover: 'https://example.com/live2.jpg',
    status: 'upcoming',
    viewers: 0,
    likes: 0
  }
]

const mockGames: Game[] = [
  {
    id: 1,
    name: '中国象棋',
    icon: 'https://example.com/chess.png',
    players: 89,
    type: 'board',
    description: '经典的中国象棋游戏'
  },
  {
    id: 2,
    name: '五子棋',
    icon: 'https://example.com/gobang.png',
    players: 56,
    type: 'board',
    description: '简单易学的五子棋游戏'
  }
]

const mockBooks: Book[] = [
  {
    id: 1,
    title: '养生保健指南',
    author: '李医生',
    cover: 'https://example.com/book1.jpg',
    progress: 45,
    category: 'health',
    description: '全面的养生保健知识'
  },
  {
    id: 2,
    title: '诗词鉴赏',
    author: '王教授',
    cover: 'https://example.com/book2.jpg',
    progress: 30,
    category: 'culture',
    description: '经典诗词赏析与解读'
  }
]

const mockGroups: InterestGroup[] = [
  {
    id: 1,
    name: '书法爱好者',
    members: 35,
    tags: ['书法', '文化'],
    joined: true,
    description: '交流书法心得，分享书法作品',
    activities: 12
  },
  {
    id: 2,
    name: '棋艺交流',
    members: 28,
    tags: ['象棋', '五子棋'],
    joined: false,
    description: '棋类爱好者交流平台',
    activities: 8
  }
]

// 模拟 API 接口
export const entertainmentApi = {
  // 获取课程列表
  async getCourses(category?: string): Promise<Course[]> {
    await delay(300)
    return category
      ? mockCourses.filter(course => course.category === category)
      : mockCourses
  },

  // 获取课程详情
  async getCourseDetail(id: number): Promise<Course | undefined> {
    await delay(200)
    return mockCourses.find(course => course.id === id)
  },

  // 更新学习进度
  async updateProgress(courseId: number, progress: number): Promise<void> {
    await delay(200)
    const course = mockCourses.find(c => c.id === courseId)
    if (course) {
      course.progress = progress
    }
  },

  // 获取直播频道
  async getLiveChannels(): Promise<LiveChannel[]> {
    await delay(300)
    return mockLiveChannels
  },

  // 开始直播
  async startLive(channelId: number): Promise<void> {
    await delay(500)
    const channel = mockLiveChannels.find(c => c.id === channelId)
    if (channel) {
      channel.status = 'live'
    }
  },

  // 点赞直播
  async likeLive(channelId: number): Promise<void> {
    await delay(200)
    const channel = mockLiveChannels.find(c => c.id === channelId)
    if (channel) {
      channel.likes++
    }
  },

  // 获取游戏列表
  async getGames(type?: string): Promise<Game[]> {
    await delay(300)
    return type
      ? mockGames.filter(game => game.type === type)
      : mockGames
  },

  // 获取电子书列表
  async getBooks(category?: string): Promise<Book[]> {
    await delay(300)
    return category
      ? mockBooks.filter(book => book.category === category)
      : mockBooks
  },

  // 更新阅读进度
  async updateReadingProgress(bookId: number, progress: number): Promise<void> {
    await delay(200)
    const book = mockBooks.find(b => b.id === bookId)
    if (book) {
      book.progress = progress
    }
  },

  // 获取兴趣小组
  async getGroups(): Promise<InterestGroup[]> {
    await delay(300)
    return mockGroups
  },

  // 加入/退出小组
  async toggleGroupMembership(groupId: number): Promise<void> {
    await delay(300)
    const group = mockGroups.find(g => g.id === groupId)
    if (group) {
      group.joined = !group.joined
      group.members += group.joined ? 1 : -1
    }
  },

  // 保存学习笔记
  async saveNote(courseId: number, note: string): Promise<void> {
    await delay(300)
    console.log(`保存课程${courseId}的笔记：${note}`)
  },

  // 获取学习统计
  async getLearningStats(): Promise<{
    totalTime: number
    completedCourses: number
    certificates: number
  }> {
    await delay(300)
    return {
      totalTime: 1500, // 分钟
      completedCourses: 5,
      certificates: 2
    }
  }
} 