// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface HealthData {
  id: number
  type: string
  value: string
  unit: string
  time: string
  status: 'normal' | 'warning' | 'danger'
}

export interface MedicineReminder {
  id: number
  medicine: string
  time: string
  status: 'pending' | 'done'
  dosage: string
  notes?: string
}

export interface Appointment {
  id: number
  date: string
  time: string
  department: string
  doctor: string
  status: 'pending' | 'confirmed' | 'cancelled'
  description?: string
}

export interface MedicalRecord {
  id: number
  date: string
  type: string
  title: string
  description: string
  doctor: string
  hospital: string
  attachments?: Array<{
    name: string
    url: string
    type: string
  }>
}

// 模拟数据
const mockHealthData: HealthData[] = [
  {
    id: 1,
    type: 'bloodPressure',
    value: '120/80',
    unit: 'mmHg',
    time: '2024-03-20 08:00',
    status: 'normal'
  },
  {
    id: 2,
    type: 'heartRate',
    value: '75',
    unit: 'bpm',
    time: '2024-03-20 08:00',
    status: 'normal'
  },
  {
    id: 3,
    type: 'bloodSugar',
    value: '5.6',
    unit: 'mmol/L',
    time: '2024-03-20 08:00',
    status: 'normal'
  }
]

const mockReminders: MedicineReminder[] = [
  {
    id: 1,
    medicine: '降压药',
    time: '08:00',
    status: 'done',
    dosage: '1片',
    notes: '饭后服用'
  },
  {
    id: 2,
    medicine: '维生素',
    time: '12:00',
    status: 'pending',
    dosage: '1粒',
    notes: '随餐服用'
  }
]

const mockAppointments: Appointment[] = [
  {
    id: 1,
    date: '2024-03-25',
    time: '09:30',
    department: '心内科',
    doctor: '张医生',
    status: 'confirmed',
    description: '常规检查'
  },
  {
    id: 2,
    date: '2024-03-28',
    time: '14:00',
    department: '骨科',
    doctor: '李医生',
    status: 'pending',
    description: '关节疼痛'
  }
]

const mockRecords: MedicalRecord[] = [
  {
    id: 1,
    date: '2024-03-15',
    type: 'examination',
    title: '年度体检',
    description: '各项指标正常',
    doctor: '王医生',
    hospital: '市第一医院',
    attachments: [
      {
        name: '体检报告.pdf',
        url: 'https://example.com/report1.pdf',
        type: 'pdf'
      }
    ]
  },
  {
    id: 2,
    date: '2024-03-10',
    type: 'treatment',
    title: '感冒就诊',
    description: '上呼吸道感染',
    doctor: '刘医生',
    hospital: '社区医院',
    attachments: [
      {
        name: '处方单.jpg',
        url: 'https://example.com/prescription1.jpg',
        type: 'image'
      }
    ]
  }
]

// 科室列表
export const departments = [
  { label: '内科', value: 'internal' },
  { label: '外科', value: 'surgery' },
  { label: '骨科', value: 'orthopedics' },
  { label: '心内科', value: 'cardiology' },
  { label: '神经科', value: 'neurology' },
  { label: '眼科', value: 'ophthalmology' },
  { label: '口腔科', value: 'dentistry' },
  { label: '耳鼻喉科', value: 'ent' }
]

// 记录类型
export const recordTypes = [
  { label: '体检记录', value: 'examination' },
  { label: '就医记录', value: 'treatment' },
  { label: '检查报告', value: 'report' },
  { label: '处方记录', value: 'prescription' }
]

// 模拟 API 接口
export const medicalApi = {
  // 获取健康数据
  async getHealthData(): Promise<HealthData[]> {
    await delay(300)
    return mockHealthData
  },

  // 获取用药提醒
  async getMedicineReminders(): Promise<MedicineReminder[]> {
    await delay(300)
    return mockReminders
  },

  // 添加用药提醒
  async addMedicineReminder(reminder: Omit<MedicineReminder, 'id'>): Promise<MedicineReminder> {
    await delay(300)
    const newReminder = {
      id: mockReminders.length + 1,
      ...reminder
    }
    mockReminders.push(newReminder)
    return newReminder
  },

  // 更新用药状态
  async updateMedicineStatus(id: number, status: 'done' | 'pending'): Promise<void> {
    await delay(200)
    const reminder = mockReminders.find(r => r.id === id)
    if (reminder) {
      reminder.status = status
    }
  },

  // 获取预约列表
  async getAppointments(): Promise<Appointment[]> {
    await delay(300)
    return mockAppointments
  },

  // 创建预约
  async createAppointment(appointment: Omit<Appointment, 'id'>): Promise<Appointment> {
    await delay(500)
    const newAppointment = {
      id: mockAppointments.length + 1,
      ...appointment
    }
    mockAppointments.push(newAppointment)
    return newAppointment
  },

  // 取消预约
  async cancelAppointment(id: number): Promise<void> {
    await delay(300)
    const appointment = mockAppointments.find(a => a.id === id)
    if (appointment) {
      appointment.status = 'cancelled'
    }
  },

  // 获取医疗记录
  async getMedicalRecords(): Promise<MedicalRecord[]> {
    await delay(300)
    return mockRecords
  },

  // 添加医疗记录
  async addMedicalRecord(record: Omit<MedicalRecord, 'id'>): Promise<MedicalRecord> {
    await delay(500)
    const newRecord = {
      id: mockRecords.length + 1,
      ...record
    }
    mockRecords.unshift(newRecord)
    return newRecord
  },

  // 上传文件（模拟）
  async uploadFile(file: File): Promise<string> {
    await delay(1000)
    return `https://example.com/files/${file.name}`
  },

  // 生成健康报告
  async generateHealthReport(): Promise<string> {
    await delay(1500)
    return 'https://example.com/health_report.pdf'
  },

  // 获取可预约时间段
  async getAvailableTimeSlots(date: string, department: string): Promise<string[]> {
    await delay(300)
    // 模拟可用时间段
    return [
      '09:00',
      '09:30',
      '10:00',
      '10:30',
      '14:00',
      '14:30',
      '15:00',
      '15:30'
    ]
  },

  // 获取医生列表
  async getDoctors(department: string): Promise<Array<{ id: number, name: string, title: string }>> {
    await delay(300)
    return [
      { id: 1, name: '张医生', title: '主任医师' },
      { id: 2, name: '李医生', title: '副主任医师' },
      { id: 3, name: '王医生', title: '主治医师' }
    ]
  }
} 