// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface News {
  id: number
  title: string
  summary: string
  content: string
  image: string
  category: string
  time: string
  views: number
  source: string
  tags: string[]
  status: 'published' | 'draft'
}

export interface NewsCategory {
  value: string
  label: string
  count: number
}

export interface NewsComment {
  id: number
  newsId: number
  userId: number
  userName: string
  content: string
  time: string
  likes: number
  replies?: NewsComment[]
}

// 模拟数据
const mockNews: News[] = [
  {
    id: 1,
    title: '老年人健康管理新政策出台',
    summary: '国家发布新政策，加强老年人健康管理服务...',
    content: '详细的新闻内容...',
    image: 'https://example.com/news1.jpg',
    category: 'policy',
    time: '2024-03-20 10:30',
    views: 1234,
    source: '健康时报',
    tags: ['政策', '健康', '养老'],
    status: 'published'
  },
  {
    id: 2,
    title: '社区举办老年人趣味运动会',
    summary: '丰富多彩的活动促进老年人身心健康...',
    content: '详细的新闻内容...',
    image: 'https://example.com/news2.jpg',
    category: 'community',
    time: '2024-03-19 15:20',
    views: 856,
    source: '社区新闻',
    tags: ['活动', '运动', '社区'],
    status: 'published'
  },
  {
    id: 3,
    title: '智能养老服务平台上线',
    summary: '运用现代科技手段提升养老服务质量...',
    content: '详细的新闻内容...',
    image: 'https://example.com/news3.jpg',
    category: 'tech',
    time: '2024-03-18 09:15',
    views: 2345,
    source: '科技日报',
    tags: ['科技', '养老', '服务'],
    status: 'published'
  }
]

const mockCategories: NewsCategory[] = [
  { value: 'policy', label: '政策新闻', count: 128 },
  { value: 'health', label: '健康资讯', count: 256 },
  { value: 'community', label: '社区动态', count: 89 },
  { value: 'tech', label: '科技新闻', count: 45 },
  { value: 'entertainment', label: '文化娱乐', count: 67 }
]

const mockComments: NewsComment[] = [
  {
    id: 1,
    newsId: 1,
    userId: 10001,
    userName: '张三',
    content: '政策很实用，对我们老年人很有帮助',
    time: '2024-03-20 11:00',
    likes: 12,
    replies: [
      {
        id: 2,
        newsId: 1,
        userId: 10002,
        userName: '李四',
        content: '同意这个观点',
        time: '2024-03-20 11:30',
        likes: 3
      }
    ]
  }
]

// 模拟 API 接口
export const newsApi = {
  // 获取新闻列表
  async getNewsList(params: {
    category?: string
    page?: number
    size?: number
    keyword?: string
  }): Promise<{
    total: number
    records: News[]
  }> {
    await delay(300)
    let result = [...mockNews]
    
    if (params.category) {
      result = result.filter(news => news.category === params.category)
    }
    
    if (params.keyword) {
      const keyword = params.keyword.toLowerCase()
      result = result.filter(news => 
        news.title.toLowerCase().includes(keyword) ||
        news.summary.toLowerCase().includes(keyword)
      )
    }

    return {
      total: result.length,
      records: result.slice(
        ((params.page || 1) - 1) * (params.size || 10),
        (params.page || 1) * (params.size || 10)
      )
    }
  },

  // 获取新闻详情
  async getNewsDetail(id: number): Promise<News | undefined> {
    await delay(200)
    return mockNews.find(news => news.id === id)
  },

  // 获取新闻分类
  async getCategories(): Promise<NewsCategory[]> {
    await delay(200)
    return mockCategories
  },

  // 获取热门新闻
  async getHotNews(limit: number = 5): Promise<News[]> {
    await delay(300)
    return [...mockNews]
      .sort((a, b) => b.views - a.views)
      .slice(0, limit)
  },

  // 更新浏览量
  async updateViews(id: number): Promise<void> {
    await delay(200)
    const news = mockNews.find(n => n.id === id)
    if (news) {
      news.views += 1
    }
  },

  // 获取新闻评论
  async getComments(newsId: number): Promise<NewsComment[]> {
    await delay(300)
    return mockComments.filter(comment => comment.newsId === newsId)
  },

  // 添加评论
  async addComment(comment: Omit<NewsComment, 'id' | 'time' | 'likes'>): Promise<NewsComment> {
    await delay(300)
    const newComment = {
      id: mockComments.length + 1,
      time: new Date().toISOString(),
      likes: 0,
      ...comment
    }
    mockComments.push(newComment)
    return newComment
  },

  // 点赞评论
  async likeComment(id: number): Promise<void> {
    await delay(200)
    const comment = mockComments.find(c => c.id === id)
    if (comment) {
      comment.likes += 1
    }
  },

  // 获取相关新闻
  async getRelatedNews(id: number, limit: number = 3): Promise<News[]> {
    await delay(300)
    const currentNews = mockNews.find(n => n.id === id)
    if (!currentNews) return []

    return mockNews
      .filter(news => 
        news.id !== id && 
        (news.category === currentNews.category ||
         news.tags.some(tag => currentNews.tags.includes(tag)))
      )
      .sort(() => Math.random() - 0.5)
      .slice(0, limit)
  },

  // 订阅主题
  async subscribeTopics(topics: string[]): Promise<void> {
    await delay(300)
    console.log('订阅主题:', topics)
  },

  // 获取订阅推送
  async getSubscribedNews(userId: number): Promise<News[]> {
    await delay(300)
    return mockNews.slice(0, 3)
  }
} 