// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface UserProfile {
  id: number
  name: string
  avatar: string
  gender: string
  age: number
  phone: string
  email: string
  address: string
  emergencyContacts: EmergencyContact[]
  healthInfo: HealthInfo
  preferences: UserPreferences
}

export interface EmergencyContact {
  id: number
  name: string
  relation: string
  phone: string
  isDefault: boolean
}

export interface HealthInfo {
  bloodType: string
  allergies: string[]
  chronicDiseases: string[]
  medications: string[]
  height: number
  weight: number
}

export interface UserPreferences {
  theme: string
  fontSize: number
  notification: boolean
  language: string
  accessibility: {
    voiceControl: boolean
    highContrast: boolean
    textToSpeech: boolean
  }
}

// 模拟数据
const mockProfile: UserProfile = {
  id: 10001,
  name: '张三',
  avatar: 'https://example.com/avatar.jpg',
  gender: '男',
  age: 65,
  phone: '13800138000',
  email: 'zhangsan@example.com',
  address: '北京市朝阳区幸福小区1号楼2单元301',
  emergencyContacts: [
    {
      id: 1,
      name: '张小明',
      relation: '子女',
      phone: '13900139000',
      isDefault: true
    },
    {
      id: 2,
      name: '李医生',
      relation: '主治医师',
      phone: '13800138001',
      isDefault: false
    }
  ],
  healthInfo: {
    bloodType: 'A',
    allergies: ['花粉', '海鲜'],
    chronicDiseases: ['高血压', '糖尿病'],
    medications: ['降压药', '降糖药'],
    height: 170,
    weight: 65
  },
  preferences: {
    theme: 'light',
    fontSize: 16,
    notification: true,
    language: 'zh-CN',
    accessibility: {
      voiceControl: true,
      highContrast: false,
      textToSpeech: true
    }
  }
}

// 模拟 API 接口
export const profileApi = {
  // 获取用户资料
  async getProfile(): Promise<UserProfile> {
    await delay(300)
    return mockProfile
  },

  // 更新基本信息
  async updateProfile(data: Partial<UserProfile>): Promise<void> {
    await delay(500)
    Object.assign(mockProfile, data)
  },

  // 更新头像
  async updateAvatar(file: File): Promise<string> {
    await delay(1000)
    const avatarUrl = URL.createObjectURL(file)
    mockProfile.avatar = avatarUrl
    return avatarUrl
  },

  // 添加紧急联系人
  async addEmergencyContact(contact: Omit<EmergencyContact, 'id'>): Promise<EmergencyContact> {
    await delay(300)
    const newContact = {
      id: mockProfile.emergencyContacts.length + 1,
      ...contact
    }
    mockProfile.emergencyContacts.push(newContact)
    return newContact
  },

  // 删除紧急联系人
  async deleteEmergencyContact(id: number): Promise<void> {
    await delay(300)
    mockProfile.emergencyContacts = mockProfile.emergencyContacts.filter(
      contact => contact.id !== id
    )
  },

  // 设置默认紧急联系人
  async setDefaultContact(id: number): Promise<void> {
    await delay(200)
    mockProfile.emergencyContacts.forEach(contact => {
      contact.isDefault = contact.id === id
    })
  },

  // 更新健康信息
  async updateHealthInfo(data: Partial<HealthInfo>): Promise<void> {
    await delay(300)
    Object.assign(mockProfile.healthInfo, data)
  },

  // 更新用户偏好设置
  async updatePreferences(data: Partial<UserPreferences>): Promise<void> {
    await delay(300)
    Object.assign(mockProfile.preferences, data)
  },

  // 修改密码
  async changePassword(data: {
    oldPassword: string
    newPassword: string
  }): Promise<void> {
    await delay(500)
    // 模拟密码修改
    console.log('密码已修改:', data)
  },

  // 验证手机号
  async verifyPhone(phone: string, code: string): Promise<boolean> {
    await delay(300)
    return code === '123456' // 模拟验证码检查
  },

  // 发送验证码
  async sendVerificationCode(phone: string): Promise<void> {
    await delay(300)
    console.log('验证码已发送到:', phone)
  },

  // 绑定邮箱
  async bindEmail(email: string, code: string): Promise<void> {
    await delay(500)
    mockProfile.email = email
  },

  // 获取账号安全等级
  async getSecurityLevel(): Promise<{
    level: 'low' | 'medium' | 'high'
    score: number
    suggestions: string[]
  }> {
    await delay(300)
    return {
      level: 'medium',
      score: 75,
      suggestions: [
        '建议开启双因素认证',
        '定期更新密码',
        '绑定备用手机号'
      ]
    }
  }
} 