// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 接口类型定义
export interface Service {
  id: number
  name: string
  description: string
  icon: string
  color: string
  types?: Array<{
    label: string
    value: string
  }>
}

export interface ServiceOrder {
  id: number
  serviceId: number
  type: string
  date: string
  time: string
  address: string
  status: 'pending' | 'confirmed' | 'processing' | 'completed' | 'cancelled'
  notes?: string
  price: number
  worker?: {
    id: number
    name: string
    phone: string
    avatar: string
    rating: number
  }
}

export interface GroupBuyItem {
  id: number
  title: string
  description: string
  image: string
  price: number
  originalPrice: number
  participants: number
  target: number
  endTime: string
  status: 'ongoing' | 'upcoming' | 'ended'
}

export interface Bill {
  id: number
  title: string
  amount: number
  dueDate: string
  type: string
  status: 'unpaid' | 'paid'
  icon: string
  color: string
}

// 模拟数据
const mockServices: Service[] = [
  {
    id: 1,
    name: '家政服务',
    description: '专业保洁、护理等服务',
    icon: 'House',
    color: '#409EFF',
    types: [
      { label: '日常保洁', value: 'cleaning' },
      { label: '深度保洁', value: 'deep-cleaning' },
      { label: '护理服务', value: 'care' }
    ]
  },
  {
    id: 2,
    name: '快递代收',
    description: '快递代收和暂存服务',
    icon: 'Box',
    color: '#67C23A'
  },
  {
    id: 3,
    name: '水电缴费',
    description: '水电费在线缴纳',
    icon: 'Money',
    color: '#E6A23C'
  }
]

const mockOrders: ServiceOrder[] = [
  {
    id: 1,
    serviceId: 1,
    type: 'cleaning',
    date: '2024-03-21',
    time: '09:00',
    address: '幸福小区1号楼2单元301',
    status: 'confirmed',
    notes: '需要带清洁工具',
    price: 150,
    worker: {
      id: 1,
      name: '张阿姨',
      phone: '13800138000',
      avatar: 'https://example.com/avatar1.jpg',
      rating: 4.8
    }
  }
]

const mockGroupBuyItems: GroupBuyItem[] = [
  {
    id: 1,
    title: '新鲜水果礼盒',
    description: '精选时令水果，营养美味',
    image: 'https://example.com/fruits.jpg',
    price: 99,
    originalPrice: 158,
    participants: 35,
    target: 50,
    endTime: '2024-03-25 23:59:59',
    status: 'ongoing'
  }
]

const mockBills: Bill[] = [
  {
    id: 1,
    title: '水费',
    amount: 85.5,
    dueDate: '2024-03-25',
    type: 'water',
    status: 'unpaid',
    icon: 'WaterMeter',
    color: '#409EFF'
  },
  {
    id: 2,
    title: '电费',
    amount: 156.8,
    dueDate: '2024-03-25',
    type: 'electricity',
    status: 'unpaid',
    icon: 'Lightning',
    color: '#E6A23C'
  }
]

// 模拟 API 接口
export const serviceApi = {
  // 获取服务列表
  async getServices(): Promise<Service[]> {
    await delay(300)
    return mockServices
  },

  // 创建服务订单
  async createOrder(order: Omit<ServiceOrder, 'id' | 'status' | 'worker'>): Promise<ServiceOrder> {
    await delay(500)
    const newOrder = {
      id: mockOrders.length + 1,
      status: 'pending' as const,
      ...order
    }
    mockOrders.push(newOrder)
    return newOrder
  },

  // 获取订单列表
  async getOrders(status?: ServiceOrder['status']): Promise<ServiceOrder[]> {
    await delay(300)
    return status 
      ? mockOrders.filter(order => order.status === status)
      : mockOrders
  },

  // 取消订单
  async cancelOrder(id: number): Promise<void> {
    await delay(300)
    const order = mockOrders.find(o => o.id === id)
    if (order) {
      order.status = 'cancelled'
    }
  },

  // 获取团购列表
  async getGroupBuyItems(status?: GroupBuyItem['status']): Promise<GroupBuyItem[]> {
    await delay(300)
    return status
      ? mockGroupBuyItems.filter(item => item.status === status)
      : mockGroupBuyItems
  },

  // 参与团购
  async joinGroupBuy(id: number): Promise<void> {
    await delay(300)
    const item = mockGroupBuyItems.find(i => i.id === id)
    if (item) {
      item.participants++
    }
  },

  // 获取账单列表
  async getBills(status?: Bill['status']): Promise<Bill[]> {
    await delay(300)
    return status
      ? mockBills.filter(bill => bill.status === status)
      : mockBills
  },

  // 支付账单
  async payBill(id: number): Promise<void> {
    await delay(500)
    const bill = mockBills.find(b => b.id === id)
    if (bill) {
      bill.status = 'paid'
    }
  },

  // 批量支付账单
  async batchPayBills(ids: number[]): Promise<void> {
    await delay(800)
    ids.forEach(id => {
      const bill = mockBills.find(b => b.id === id)
      if (bill) {
        bill.status = 'paid'
      }
    })
  }
} 