// 模拟延迟
const delay = (ms: number) => new Promise(resolve => setTimeout(resolve, ms))

// 视频数据接口
export interface Video {
  id: number
  title: string
  url: string
  thumbnail: string
  duration: string
  category: string
  views: number
  description: string
  uploadTime: string
  likes: number
  comments: number
  tags: string[]
}

// 模拟视频数据
const mockVideos: Video[] = [
  {
    id: 1,
    title: '每日健康操',
    url: 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4',
    thumbnail: 'https://peach.blender.org/wp-content/uploads/bbb-splash.png',
    duration: '10:00',
    category: 'health',
    views: 1234,
    description: '适合老年人的健康运动视频',
    uploadTime: '2024-03-20',
    likes: 256,
    comments: 45,
    tags: ['健康', '运动', '教学']
  },
  {
    id: 2,
    title: '养生保健知识讲座',
    url: 'https://media.w3.org/2010/05/sintel/trailer.mp4',
    thumbnail: 'https://durian.blender.org/wp-content/uploads/2010/05/sintel_trailer_1080.jpg',
    duration: '15:30',
    category: 'health',
    views: 2345,
    description: '专业��生讲解养生知识',
    uploadTime: '2024-03-19',
    likes: 342,
    comments: 67,
    tags: ['养生', '健康', '讲座']
  },
  {
    id: 3,
    title: '24式太极拳教学',
    url: 'https://media.w3.org/2010/05/video/movie_300.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/elderly-people-doing-tai-chi_23-2148965375.jpg',
    duration: '45:00',
    category: 'health',
    views: 3456,
    description: '专业老师讲解24式太极拳基本动作要领',
    uploadTime: '2024-03-18',
    likes: 567,
    comments: 89,
    tags: ['太极拳', '运动', '教学']
  },
  {
    id: 4,
    title: '经典戏曲欣赏',
    url: 'https://vjs.zencdn.net/v/oceans.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/chinese-opera-performer_1159-819.jpg',
    duration: '25:00',
    category: 'entertainment',
    views: 4567,
    description: '传统戏曲表演精选',
    uploadTime: '2024-03-17',
    likes: 678,
    comments: 123,
    tags: ['戏曲', '文化', '艺术']
  },
  {
    id: 5,
    title: '广场舞教学',
    url: 'http://clips.vorwaerts-gmbh.de/big_buck_bunny.mp4',
    thumbnail: 'https://img.freepik.com/free-photo/group-elderly-people-dancing_23-2148965384.jpg',
    duration: '30:00',
    category: 'entertainment',
    views: 5678,
    description: '广场舞基础动作教学',
    uploadTime: '2024-03-16',
    likes: 789,
    comments: 234,
    tags: ['广场舞', '运动', '教学']
  }
]

// 视频分类
export const videoCategories = [
  { label: '全部', value: '' },
  { label: '健康讲座', value: 'health' },
  { label: '娱乐节目', value: 'entertainment' },
  { label: '新闻资讯', value: 'news' }
]

// 模拟 API 接口
export const videoApi = {
  // 获取视频列表
  async getVideoList(category: string = ''): Promise<Video[]> {
    await delay(500) // 模拟网络延迟
    return mockVideos.filter(video => 
      category ? video.category === category : true
    )
  },

  // 获取视频详情
  async getVideoDetail(id: number): Promise<Video | undefined> {
    await delay(300)
    return mockVideos.find(video => video.id === id)
  },

  // 更新观看次数
  async updateViews(id: number): Promise<void> {
    await delay(200)
    const video = mockVideos.find(v => v.id === id)
    if (video) {
      video.views += 1
    }
  },

  // 点赞视频
  async likeVideo(id: number): Promise<void> {
    await delay(200)
    const video = mockVideos.find(v => v.id === id)
    if (video) {
      video.likes += 1
    }
  },

  // 获取推荐视频
  async getRecommendedVideos(currentId: number): Promise<Video[]> {
    await delay(300)
    return mockVideos
      .filter(video => video.id !== currentId)
      .sort(() => Math.random() - 0.5)
      .slice(0, 3)
  },

  // 获取热门视频
  async getHotVideos(): Promise<Video[]> {
    await delay(300)
    return [...mockVideos]
      .sort((a, b) => b.views - a.views)
      .slice(0, 5)
  }
} 